@@ -2,4 +2,4 @@
 Finds and reports valid Google Service Account keys on your filesystem
 """
 
-from find_gcp_keys.__main__ import find_key_paths, is_valid_key, search
+from find_gcp_keys.__main__ import find_key_paths, find_valid_keys, is_valid_key
